(window.webpackJsonp=window.webpackJsonp||[]).push([[12],{"9D7j":function(e,n,t){"use strict";t.r(n);var r=t("p0pE"),u=t.n(r),a=t("d6i3"),c=t.n(a),o=t("jHYr"),p=t.n(o),s=t("io9h");function i(){return Object(s.a)("/api/count")}var f={namespace:"countPage",state:{namespaceNum:0,resourceNum:0,functionNum:0,fileNum:0},effects:{fetch:c.a.mark(function e(n,t){var r,u,a;return c.a.wrap(function(e){for(;;)switch(e.prev=e.next){case 0:return p()(n),r=t.call,u=t.put,e.next=4,r(i);case 4:return a=e.sent,e.next=7,u({type:"update",payload:void 0!==a?a:{}});case 7:case"end":return e.stop()}},e)})},reducers:{update:function(e,n){return u()({},e,n.payload)}}};n.default=f},jHYr:function(e,n){e.exports=function(e){if(null==e)throw new TypeError("Cannot destructure undefined")}}}]);