(window.webpackJsonp=window.webpackJsonp||[]).push([[5],{Xfv2:function(e,t,n){e.exports={normal:"antd-pro-pages-resources-index.css-normal",baseInfo:"antd-pro-pages-resources-index.css-baseInfo"}},mB2O:function(e,t,n){"use strict";n.r(t);n("IzEo");var a=n("bx4M"),r=(n("jCWc"),n("kPKH")),o=(n("14J3"),n("BMrR")),c=(n("h7lp"),n("bf48")),u=n("2Taf"),l=n.n(u),s=n("vZ4D"),i=n.n(s),p=n("l4Ni"),f=n.n(p),m=n("ujKo"),d=n.n(m),b=n("MhPg"),E=n.n(b),h=n("q1tI"),g=n.n(h),v=n("Xfv2"),y=n.n(v),w=n("MuoO"),j=function(e,t,n,a){var r,o=arguments.length,c=o<3?t:null===a?a=Object.getOwnPropertyDescriptor(t,n):a;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)c=Reflect.decorate(e,t,n,a);else for(var u=e.length-1;u>=0;u--)(r=e[u])&&(c=(o<3?r(c):o>3?r(t,n,c):r(t,n))||c);return o>3&&c&&Object.defineProperty(t,n,c),c},k=function(e){function t(){return l()(this,t),f()(this,d()(t).apply(this,arguments))}return E()(t,e),i()(t,[{key:"componentDidMount",value:function(){(0,this.props.dispatch)({type:"countPage/fetch"})}},{key:"render",value:function(){var e=this.props.count;return g.a.createElement(g.a.Fragment,null,g.a.createElement(c.a,{onBack:function(){return null},title:"资源统计",subTitle:"数据大屏"}),g.a.createElement("div",{className:y.a.baseInfo},g.a.createElement(o.a,{gutter:16},g.a.createElement(r.a,{span:6},g.a.createElement(a.a,{title:"命名空间",bordered:!1},e.namespaceNum)),g.a.createElement(r.a,{span:6},g.a.createElement(a.a,{title:"数据源",bordered:!1},e.resourceNum)),g.a.createElement(r.a,{span:6},g.a.createElement(a.a,{title:"函数",bordered:!1},e.functionNum)),g.a.createElement(r.a,{span:6},g.a.createElement(a.a,{title:"文件",bordered:!1},e.fileNum)))))}}]),t}(h.Component),N=k=j([Object(w.connect)(function(e){return{count:e.countPage}})],k);t.default=N}}]);